@@ -979,8 +979,8 @@ AMP_NET_DIR_TEMPLATE = '/etc/octavia/interfaces/'
 NFT_ADD = 'add'
 NFT_CMD = '/usr/sbin/nft'
 NFT_FAMILY = 'inet'
-NFT_VIP_RULES_FILE = '/var/lib/octavia/nftables-vip.rules'
-NFT_VIP_TABLE = 'amphora_vip'
+NFT_RULES_FILE = '/var/lib/octavia/nftables-vip.rules'
+NFT_TABLE = 'amphora_table'
+NFT_CHAIN = 'amphora_chain'
 NFT_VIP_CHAIN = 'amphora_vip_chain'
-NFT_SRIOV_PRIORITY = '-310'
 PROTOCOL = 'protocol'
